@@ -53,18 +53,18 @@ Diagram::Diagram()
 {
   SetBackground(Lum::OS::display->GetFill(Lum::OS::Display::graphBackgroundFillIndex));
 
-  AttachModel(topWeight);
-  AttachModel(bottomWeight);
-  AttachModel(maxWeight);
-  AttachModel(minWeight);
+  Observe(topWeight);
+  Observe(bottomWeight);
+  Observe(maxWeight);
+  Observe(minWeight);
 
-  AttachModel(topValue);
-  AttachModel(bottomValue);
-  AttachModel(maxValue);
-  AttachModel(minValue);
+  Observe(topValue);
+  Observe(bottomValue);
+  Observe(maxValue);
+  Observe(minValue);
 
   // For updating the visible area to the given date
-  AttachModel(date);
+  Observe(date);
 }
 
 void Diagram::CalcSize()
