@@ -265,17 +265,17 @@ FoodInput::FoodInput()
 
    searchTimerAction(new Lum::Model::Action())
 {
-  AttachModel(foodSearch);
+  Observe(foodSearch);
 
-  AttachModel(addFoodEntryAction);
-  AttachModel(removeFoodEntryAction);
-  AttachModel(editFoodEntryAction);
-  AttachModel(registerFoodAction);
+  Observe(addFoodEntryAction);
+  Observe(removeFoodEntryAction);
+  Observe(editFoodEntryAction);
+  Observe(registerFoodAction);
 
-  AttachModel(searchTimerAction);
+  Observe(searchTimerAction);
 
-  AttachModel(goodValueLimit);
-  AttachModel(badValueLimit);
+  Observe(goodValueLimit);
+  Observe(badValueLimit);
 }
 
 void FoodInput::CalcSize()
