@@ -54,24 +54,24 @@ Preferences::Preferences()
   trendType->Push();
   trendDirection->Push();
 
-  AttachModel(okAction);
+  Observe(okAction);
 
-  AttachModel(topWeight);
-  AttachModel(bottomWeight);
-  AttachModel(maxWeight);
-  AttachModel(minWeight);
+  Observe(topWeight);
+  Observe(bottomWeight);
+  Observe(maxWeight);
+  Observe(minWeight);
 
-  AttachModel(topValue);
-  AttachModel(bottomValue);
-  AttachModel(maxValue);
-  AttachModel(minValue);
-  AttachModel(goodValueLimit);
-  AttachModel(badValueLimit);
+  Observe(topValue);
+  Observe(bottomValue);
+  Observe(maxValue);
+  Observe(minValue);
+  Observe(goodValueLimit);
+  Observe(badValueLimit);
 
-  AttachModel(refValue);
+  Observe(refValue);
 
-  AttachModel(valueUnit);
-  AttachModel(weightUnit);
+  Observe(valueUnit);
+  Observe(weightUnit);
 
   SetExitAction(GetClosedAction());
 }
